# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/ysn/mz/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/ysn/mz/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Ysn\\Mz\\": "packages/ysn/mz/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Ysn\Mz\Providers\MzServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Mz'  => Ysn\Mz\Facades\Mz::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Ysn\\MzTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Ysn\Mz\Providers\MzServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Ysn\Mz\Providers\MzServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Ysn\Mz\Providers\MzServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/mz/{modulename}

**User**

    http://path-to-route-folder/user/mz/{modulename}

**Public**

    http://path-to-route-folder/mzs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/mz/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/mz/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/mz/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/mz/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/mz/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/mz/{modulename}/{slug}
    METHOD: GET